pub enum ExprKind {
Show 28 variants
Literal(LiteralExpr),
FieldRef(FieldRefExpr),
Sizeof(SizeofExpr),
Alignof(AlignofExpr),
Add(AddExpr),
Sub(SubExpr),
Mul(MulExpr),
Div(DivExpr),
Mod(ModExpr),
Pow(PowExpr),
BitAnd(BitAndExpr),
BitOr(BitOrExpr),
BitXor(BitXorExpr),
LeftShift(LeftShiftExpr),
RightShift(RightShiftExpr),
BitNot(BitNotExpr),
Neg(NegExpr),
Not(NotExpr),
Popcount(PopcountExpr),
Eq(EqExpr),
Ne(NeExpr),
Lt(LtExpr),
Gt(GtExpr),
Le(LeExpr),
Ge(GeExpr),
And(AndExpr),
Or(OrExpr),
Xor(XorExpr),
}Variants
Literal(LiteralExpr)
FieldRef(FieldRefExpr)
Sizeof(SizeofExpr)
Alignof(AlignofExpr)
Add(AddExpr)
Sub(SubExpr)
Mul(MulExpr)
Div(DivExpr)
Mod(ModExpr)
Pow(PowExpr)
BitAnd(BitAndExpr)
BitOr(BitOrExpr)
BitXor(BitXorExpr)
LeftShift(LeftShiftExpr)
RightShift(RightShiftExpr)
BitNot(BitNotExpr)
Neg(NegExpr)
Not(NotExpr)
Popcount(PopcountExpr)
Eq(EqExpr)
Ne(NeExpr)
Lt(LtExpr)
Gt(GtExpr)
Le(LeExpr)
Ge(GeExpr)
And(AndExpr)
Or(OrExpr)
Xor(XorExpr)
Implementations
Sourceimpl ExprKind
impl ExprKind
Sourcepub fn try_evaluate_constant(&self) -> Option<u64>
pub fn try_evaluate_constant(&self) -> Option<u64>
Recursively evaluate this expression to a constant value if possible Returns None if the expression contains unresolvable references (like field refs)
Sourcepub fn to_c_string(&self) -> String
pub fn to_c_string(&self) -> String
Format the expression as a C-style mathematical expression This format is compatible with C, Rust, and TypeScript for most operations
Sourcepub fn to_debug_string(&self) -> String
pub fn to_debug_string(&self) -> String
Generate a debug string representation of the expression